@@ -1,6 +1,8 @@
 from functools import wraps
 from logging import getLogger
 
+from platypush.common import exec_wrapper
+
 logger = getLogger(__name__)
 
 
@@ -11,17 +13,7 @@ def cron(cron_expression: str):
 
         @wraps(f)
         def wrapped(*args, **kwargs):
-            from platypush import Response
-
-            try:
-                ret = f(*args, **kwargs)
-                if isinstance(ret, Response):
-                    return ret
-
-                return Response(output=ret)
-            except Exception as e:
-                logger.exception(e)
-                return Response(errors=[str(e)])
+            return exec_wrapper(f, *args, **kwargs)
 
         return wrapped
 
